==> dita-ot-4.2.3.x86_64_linux.bottle.tar.gz: dita-ot/4.2.3/libexec/config/env.sh <==
#!/bin/sh
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.htmlhelp/lib/htmlhelp.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2/lib/fo.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/com.elovirta.pdf/lib/pdf-generator-0.7.2.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.eclipsehelp/lib/eclipsehelp.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.index/lib/index.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.axf/lib/axf.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/batik-all-1.17.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fontbox-2.0.28.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fop-core-2.9.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fop-events-2.9.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fop-pdf-images-2.9.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fop-util-2.9.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/jcl-over-slf4j-2.0.7.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/pdfbox-2.0.28.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/slf4j-api-2.0.7.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/xml-apis-ext-1.3.04.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/xmlgraphics-commons-2.9.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.xep/lib/xep.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/org.lwdita-5.7.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/htmlparser-1.4.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-abbreviation-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-admonition-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-anchorlink-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-attributes-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-autolink-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-definition-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-footnotes-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-gfm-strikethrough-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-jekyll-tag-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-ins-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-superscript-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-tables-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-typographic-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-yaml-front-matter-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-format-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-ast-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-builder-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-dependency-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-html-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-sequence-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-collection-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-data-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-misc-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-visitor-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/autolink-0.6.0.jar"

==> dita-ot-4.3.3.x86_64_linux.bottle.tar.gz: dita-ot/4.3.3/libexec/config/env.sh <==
#!/bin/sh
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.htmlhelp/lib/htmlhelp.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2/lib/fo.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/com.elovirta.pdf/lib/pdf-generator-0.8.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.eclipsehelp/lib/eclipsehelp.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.index/lib/index.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.axf/lib/axf.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/batik-all-1.19.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fontbox-3.0.5.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fop-core-2.11.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fop-events-2.11.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fop-pdf-images-2.11.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/fop-util-2.11.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/jcl-over-slf4j-2.0.17.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/pdfbox-3.0.5.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/pdfbox-io-3.0.5.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/slf4j-api-2.0.17.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/xml-apis-ext-1.3.04.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.fop/lib/xmlgraphics-commons-2.11.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.dita.pdf2.xep/lib/xep.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/org.lwdita-5.9.1.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/htmlparser-1.4.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-abbreviation-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-admonition-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-anchorlink-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-attributes-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-autolink-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-definition-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-footnotes-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-gfm-strikethrough-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-jekyll-tag-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-ins-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-superscript-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-tables-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-typographic-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-ext-yaml-front-matter-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-format-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-ast-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-builder-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-dependency-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-html-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-sequence-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-collection-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-data-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-misc-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/flexmark-util-visitor-0.64.0.jar"
CLASSPATH="$CLASSPATH:$DITA_HOME/plugins/org.lwdita/lib/autolink-0.6.0.jar"
